@@ -24,12 +24,17 @@ help_ = on_command('l4_help',aliases={'求生帮助'},priority=20,block=True)
 
 
 def wenjian(
-event:GroupUploadNoticeEvent):
+event:NoticeEvent):
+    superuse = nonebot.get_driver().config.l4_master
     if isinstance(event, GroupUploadNoticeEvent):
-        superuse = nonebot.get_driver().config.l4_master
         return str(event.user_id) in superuse
     else:
-        return event.user_id != 114514
+        args = event.dict()
+        if superuse:
+            return str(args['user_id']) in superuse and args['notice_type'] == 'offline_file'
+        else:
+            return args['notice_type'] == 'offline_file'
+
 up = on_notice(rule=wenjian)
 # up = on_command('upmap',aliases={'上传地图','上传'},priority=20,block=True,permission= reMaster,handlers=[l4_up()])
 
