@@ -1,15 +1,18 @@
+
+
+from jinja2 import Environment, FileSystemLoader
+from bs4 import BeautifulSoup
+from nonebot.log import logger
 from nonebot_plugin_htmlrender import html_to_pic
+
+# from .htmlimg import dict_to_dict_img
+from ..l4d2_anne.anne_telecom import ANNE_API
 from ..config import TEXT_PATH
 try:
     from .download import get_head_steam_and_save
 except:
     from .download import get_head_by_user_id_and_save
 from .send_image_tool import convert_img
-from bs4 import BeautifulSoup
-from nonebot.log import logger
-from jinja2 import Environment, FileSystemLoader
-# from .htmlimg import dict_to_dict_img
-from ..l4d2_anne.anne_telecom import ANNE_API
 
 async def out_png(usr_id,data_dict:dict):
     """使用html来生成图片"""
@@ -18,11 +21,12 @@ async def out_png(usr_id,data_dict:dict):
         data_html = file.read()
     # content = template.render_async()
     soup = BeautifulSoup(data_html, 'html.parser')
-    new_html = await dict_to_html(usr_id,data_dict,soup)
+    msg_dict = await dict_to_html(usr_id,data_dict,soup)
     
     env = Environment(loader=FileSystemLoader(template_path))
     template = env.get_template('anne.html')
-    html = template.render(data = new_html)
+    html = template.render(data=msg_dict)
+
     
     pic = await html_to_pic(
                 html,
@@ -57,33 +61,36 @@ async def dict_to_html(usr_id,DETAIL_MAP:dict,soup:BeautifulSoup):
     # temp = await get_head_steam_and_save(usr_id,DETAIL_right['url'])
     res = await convert_img(temp,is_base64=True)
     DETAIL_right['header'] = f"data:image/png;base64,{res}"
-    data_list = [DETAIL_right]
+    data_list:list[dict] = [DETAIL_right]
     return data_list
     
 async def server_ip_pic(msg_dict:list[dict]):
     """
     输入一个字典列表，输出图片
-    msg_dict:（folder/name/map_/players/max_players/Players/[Name]）
+    msg_dict:folder/name/map_/players/max_players/Players/[Name]
     """
-    for one in msg_dict:
-        one['max_players'] = one['players'] + '/' + one['max_players']
+    for server_info in msg_dict:
+        server_info['max_players'] = f"{server_info['players']}/{server_info['max_players']}"
         players_list = []
         try:
-            for one_player in one['Players']:
-                player_str = one_player['Name'] +' | ' + one_player['Duration']
-                players_list.append(player_str)
-            one['Players'] = players_list
-    # one['Players'] = one['Players']['Name'] + one['Players']['Dutation']
+            if 'Players' in server_info:
+                sorted_players = sorted(server_info['Players'], key=lambda x: x.get('Score', 0), reverse=True)[:4]
+                for player_info in sorted_players:
+                    player_str = f"{player_info['Name']} | {player_info['Duration']}"
+                    players_list.append(player_str)
+                while len(players_list) < 4:
+                    players_list.append("")
+                server_info['Players'] = players_list
         except KeyError:
-            continue
-    # 饼状图
+            pass
+
+
+    
+    
     template_path = TEXT_PATH/"template"
     env = Environment(loader=FileSystemLoader(template_path))
     template = env.get_template('ip.html')
-    data = []
-    for i in range(0, len(msg_dict), 4):
-        data.append(msg_dict[i:i+4])
-    html = template.render(data = data)
+    html = template.render(data = msg_dict)
     with open("pie-chart.html", "w") as f:
         f.write(html)
     pic = await html_to_pic(
